@@ -21,16 +21,16 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
  *********************************************************************/
 
 #include "curveFitData.h"
 
 #include <qlabel.h>
-#include <qbttngrp.h>
-#include <qpushbt.h>
-#include <qradiobt.h>
+#include <qbuttongroup.h>
+#include <qpushbutton.h>
+#include <qradiobutton.h>
 #include <qlayout.h>
 #include <klocale.h>
 
