@@ -21,15 +21,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    ------------------------------------------------------------------------*/
 
 #include "multiFileData.h"
 
 #include <qlabel.h>
-#include <qpushbt.h>
-#include <qbttngrp.h>
+#include <qpushbutton.h>
+#include <qbuttongroup.h>
 #include <qlayout.h>
 #include <klocale.h>
 
@@ -145,7 +145,7 @@ multiFileData::multiFileData
   legendTitlenotitleButton = new QCheckBox(legendButtonGroup, "CheckBox_5" );
   legendTitlenotitleButton->setMinimumSize( 60, 20 );
   legendTitlenotitleButton->setMaximumSize( 32767, 20 );
-  legendTitlenotitleButton->setText( "&notitle" );
+  legendTitlenotitleButton->setText( i18n("&notitle") );
   legendTitlenotitleButton->setAutoRepeat( FALSE );
   //legendTitlenotitleButton->setAutoResize( FALSE );
 
